[llvm-commits] [llvm] r170630 - in /llvm/trunk: lib/CodeGen/SelectionDAG/DAGCombiner.cpp test/CodeGen/X86/2012-12-19-NoImplicitFloat.ll

Bob Wilson bob.wilson at apple.com
Wed Dec 19 17:36:20 PST 2012


Author: bwilson
Date: Wed Dec 19 19:36:20 2012
New Revision: 170630

URL: http://llvm.org/viewvc/llvm-project?rev=170630&view=rev
Log:
Do not introduce vector operations in functions marked with noimplicitfloat.

<rdar://problem/12879313>

Added:
    llvm/trunk/test/CodeGen/X86/2012-12-19-NoImplicitFloat.ll
Modified:
    llvm/trunk/lib/CodeGen/SelectionDAG/DAGCombiner.cpp

Modified: llvm/trunk/lib/CodeGen/SelectionDAG/DAGCombiner.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/CodeGen/SelectionDAG/DAGCombiner.cpp?rev=170630&r1=170629&r2=170630&view=diff
==============================================================================
--- llvm/trunk/test/CodeGen/X86/2012-12-19-NoImplicitFloat.ll (added)
+++ llvm/trunk/test/CodeGen/X86/2012-12-19-NoImplicitFloat.ll Wed Dec 19 19:36:20 2012
@@ -0,0 +1,17 @@
+; RUN: llc -mtriple=x86_64-apple-macosx10.8.0 -mcpu=core2 < %s | FileCheck %s
+; Test that we do not introduce vector operations with noimplicitfloat.
+; rdar://12879313
+
+%struct1 = type { i32*, i32* }
+
+define void @test() nounwind noimplicitfloat {
+entry:
+; CHECK-NOT: xmm
+; CHECK: ret
+  %0 = load %struct1** undef, align 8
+  %1 = getelementptr inbounds %struct1* %0, i64 0, i32 0
+  store i32* null, i32** %1, align 8
+  %2 = getelementptr inbounds %struct1* %0, i64 0, i32 1
+  store i32* null, i32** %2, align 8
+  ret void
+}





More information about the llvm-commits mailing list
--- llvm/trunk/lib/CodeGen/SelectionDAG/DAGCombiner.cpp (original)
+++ llvm/trunk/lib/CodeGen/SelectionDAG/DAGCombiner.cpp Wed Dec 19 19:36:20 2012
@@ -25,6 +25,7 @@
 #include "llvm/CodeGen/MachineFunction.h"
 #include "llvm/DataLayout.h"
 #include "llvm/DerivedTypes.h"
+#include "llvm/Function.h"
 #include "llvm/LLVMContext.h"
 #include "llvm/Support/CommandLine.h"
 #include "llvm/Support/Debug.h"
@@ -7748,8 +7749,10 @@
         LastLegalVectorType = i + 1;
     }
 
-    // We only use vectors if the constant is known to be zero.
-    if (NonZero)
+    // We only use vectors if the constant is known to be zero and the
+    // function is not marked with the noimplicitfloat attribute.
+    if (NonZero || (DAG.getMachineFunction().getFunction()->getFnAttributes().
+                    hasAttribute(Attribute::NoImplicitFloat)))
       LastLegalVectorType = 0;
 
     // Check if we found a legal integer type to store.

Added: llvm/trunk/test/CodeGen/X86/2012-12-19-NoImplicitFloat.ll
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/test/CodeGen/X86/2012-12-19-NoImplicitFloat.ll?rev=170630&view=auto
==============================================================================